
import requests
from bs4 import BeautifulSoup

def get_problem_score(problem):
    res = requests.get(f"https://open.kattis.com/problems/{problem}")
    if res.status_code == 200:
        soup = BeautifulSoup(res.text, features="html.parser")
        difficulity_title = soup.find('strong', text="Difficulty:  ")
        return float(difficulity_title.find_next_sibling("span").text)
    return 0


import requests
import configparser
import os
from pathlib import Path
import re
import webbrowser
import sys

_HEADERS = {'User-Agent': 'kattis-cli-submit'}

def get_url(cfg, option, default):
    if cfg.has_option('kattis', option):
        return cfg.get('kattis', option)
    else:
        return 'https://%s/%s' % (cfg.get('kattis', 'hostname'), default)

def get_config():
    cfg = configparser.ConfigParser()

    if not cfg.read([os.path.join(Path.home(), '.kattisrc'),
                     os.path.join(os.path.dirname(sys.argv[0]), '.kattisrc')]):
        raise EnvironmentError(
            "Couldn't find .kattisrc. Please download from https://open.kattis.com/download/kattisrc")
    return cfg
def login(login_url, username, password=None, token=None):
    login_args = {'user': username, 'script': 'true'}
    if password:
        login_args['password'] = password
    if token:
        login_args['token'] = token

    return requests.post(login_url, data=login_args, headers=_HEADERS)

def login_from_config(cfg):
    username = cfg.get('user', 'username')
    password = token = None
    try:
        password = cfg.get('user', 'password')
    except configparser.NoOptionError:
        pass
    try:
        token = cfg.get('user', 'token')
    except configparser.NoOptionError:
        pass
    if password is None and token is None:
        raise EnvironmentError('Invalid .kattisrc file')

    loginurl = get_url(cfg, 'loginurl', 'login')
    return login(loginurl, username, password, token)

def open_submission(submit_response, cfg):
    submissions_url = get_url(cfg, 'submissionsurl', 'submissions')

    m = re.search(r'Submission ID: (\d+)', submit_response)
    if m:
        submission_id = m.group(1)
        url = '%s/%s' % (submissions_url, submission_id)
        webbrowser.open(url)
            

def submit_problem(problem, sub_files, open=True):
    cfg = get_config()
    login_reply = login_from_config(cfg)

    data = {'submit': 'true',
            'submit_ctr': 2,
            'language': 'Python 3',
            'mainclass': 'solution.py',
            'problem': problem,
            'tag': '',
            'script': 'true'}

    result = requests.post(get_url(cfg, 'submissionurl', 'submit'), data=data, files=sub_files, cookies=login_reply.cookies, headers=_HEADERS)

    plain_result = result.content.decode('utf-8').replace('<br />', '\n')
    print(plain_result)
    
    if open: open_submission(plain_result, cfg)


__version__ = "0.1.0"

import click
import requests
import zipfile
import tempfile
import glob
import subprocess
import colorful as cf
import re
import os
import sys
import webbrowser
from kattiskitten.tester import test_problem
from kattiskitten.scraper import get_problem_score
from kattiskitten.submitter import submit_problem
from kattiskitten.languages import languages

__author__ = "Felix Qvist"

@click.group()
def main():
    """
    Simple CLI for downloading and testing kattis problems
    """
    pass

@main.command()
def problems():
    """
    Simply opens https://open.kattis.com/problems in your webbrowser
    """
    webbrowser.open("https://open.kattis.com/problems")
    

@main.command()
@click.argument('problem')
def test(problem):
    """This tests a kattis problem using provided test problems"""
    if problem == 'all':
        problems = glob.glob(f"./*/")

        completed_count = 0
        total_score = 0
        earned_score = 0
        for p in problems:
            p = re.sub(r'[^\w]', '', p)
            res = test_problem(p, False)
            score = get_problem_score(p)
            total_score += score
            if res:
                print(f"✅ {p}")
                completed_count += 1
                earned_score += score
            else:
                print(f"❌ {p}")

        print(f"\n Completed {completed_count}/{len(problems)}")
        print(f"\n Earned {round(earned_score)}/{round(total_score)} points")

    else:
        res = test_problem(problem)
        if res:
            print(f"Earned {get_problem_score(problem)} points 🎉")


@main.command()
@click.option("--language", default="python3")
@click.argument('problem')
def get(problem, language):
    """This command downloads a kattis problem and test files"""
    res = requests.get(
        f"https://open.kattis.com/problems/{problem}/file/statement/samples.zip")

    language_config = languages.get_config(language)
    
    if res.status_code == 404:
        print(f"Couldn't find problem '{problem}'. Maybe you typed it wrong? Or no test files exist")
    else:
        print("Downloading samples")
        tmp_file = tempfile.NamedTemporaryFile(delete=False)
        open(tmp_file.name, 'wb').write(res.content)

        with zipfile.ZipFile(tmp_file.name, 'r') as zip_ref:
            zip_ref.extractall(f'./{problem}')
            print(f"Samples downloaded to './{problem}'")
        tmp_file.close()
        os.unlink(tmp_file.name)


        # Create main.xx with template
        if not os.path.exists(f'./{problem}/solution.{language_config.file_extension}'):
            open(f'./{problem}/solution.{language_config.file_extension}', 'w').write(language_config.default_content)


@main.command()
@click.argument('problem')
def submit(problem):
    """This command submits a problem to kattis"""
    f = f'./{problem}/solution.py'

    sub_files = []
    with open(f) as sub_file:
        sub_files.append(('sub_file[]', (os.path.basename(
            f), sub_file.read(), 'application/octet-stream')))

    submit_problem(problem, sub_files)

if __name__ == "__main__":
    main()



import glob
import re
import kattiskitten.languages.python3.config as python3_config
import kattiskitten.languages.java.config as java_config

SUPPORTED_LANGUAGES = ["python3", "java"]

LANGUAGE_EXTENSIONS = {
    ".py": "python3",
    ".java": "java",
}


def get_config(language):
    if language == "python3":
        return python3_config
    if language == "java":
        return java_config

    raise ValueError(f"Language not supported. Supported languages are: {', '.join(SUPPORTED_LANGUAGES)}")


def determine_language(problem):
    solution = glob.glob(f"./{problem}/solution.*")

    if len(solution) < 1:
        raise ValueError("Couldn't find any program matching patten (solution.*)")
    if len(solution) > 1:
        raise ValueError(
            "Found more than one program matching patten (solution.*). It currently only supports one")

    m = re.search(r".*(\..+?)$", solution[0])

    if m:
        extension = m.group(1)
        language = LANGUAGE_EXTENSIONS[extension]
        if not language:
            raise ValueError(
                f"Couldn't find supported language with extension {extension}")

        return language
